@@ -12,7 +12,7 @@
     License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+    along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
 
 #include "sortutil.h"
@@ -29,6 +29,7 @@
 #include <KItinerary/Visit>
 
 #include <QDateTime>
+#include <QTimeZone>
 
 using namespace KItinerary;
 
@@ -45,7 +46,11 @@ QDateTime SortUtil::startDateTime(const QVariant &res)
         return QDateTime(flight.departureDay(), QTime(23, 59, 59));
     }
     if (JsonLd::isA<TrainReservation>(res)) {
-        return res.value<TrainReservation>().reservationFor().value<TrainTrip>().departureTime();
+        const auto trip = res.value<TrainReservation>().reservationFor().value<TrainTrip>();
+        if (trip.departureTime().isValid()) {
+            return trip.departureTime();
+        }
+        return QDateTime(trip.departureDay(), QTime(23, 59, 59));
     }
     if (JsonLd::isA<BusReservation>(res)) {
         return res.value<BusReservation>().reservationFor().value<BusTrip>().departureTime();
@@ -59,7 +64,11 @@ QDateTime SortUtil::startDateTime(const QVariant &res)
     if (JsonLd::isA<LodgingReservation>(res)) {
         const auto hotel = res.value<LodgingReservation>();
         // hotel checkin/checkout is always considered the first/last thing of the day
-        return QDateTime(hotel.checkinTime().date(), QTime(23, 59, 59));
+        auto dt = QDateTime(hotel.checkinTime().date(), QTime(23, 59, 59));
+        if (hotel.checkinTime().timeSpec() == Qt::TimeZone) {
+            dt.setTimeZone(hotel.checkinTime().timeZone());
+        }
+        return dt;
     }
     if (JsonLd::isA<TouristAttractionVisit>(res)) {
         return res.value<TouristAttractionVisit>().arrivalTime();
@@ -84,7 +93,11 @@ QDateTime SortUtil::endtDateTime(const QVariant &res)
         return QDateTime(flight.departureDay(), QTime(23, 59, 59));
     }
     if (JsonLd::isA<TrainReservation>(res)) {
-        return res.value<TrainReservation>().reservationFor().value<TrainTrip>().arrivalTime();
+        const auto trip = res.value<TrainReservation>().reservationFor().value<TrainTrip>();
+        if (trip.arrivalTime().isValid()) {
+            return trip.arrivalTime();
+        }
+        return QDateTime(trip.departureDay(), QTime(23, 59, 59));
     }
     if (JsonLd::isA<BusReservation>(res)) {
         return res.value<BusReservation>().reservationFor().value<BusTrip>().arrivalTime();
@@ -103,7 +116,11 @@ QDateTime SortUtil::endtDateTime(const QVariant &res)
     if (JsonLd::isA<LodgingReservation>(res)) {
         const auto hotel = res.value<LodgingReservation>();
         // hotel checkin/checkout is always considered the first/last thing of the day
-        return QDateTime(hotel.checkoutTime().date(), QTime(0, 0, 0));
+        auto dt = QDateTime(hotel.checkoutTime().date(), QTime(0, 0, 0));
+        if (hotel.checkoutTime().timeSpec() == Qt::TimeZone) {
+            dt.setTimeZone(hotel.checkoutTime().timeZone());
+        }
+        return dt;
     }
     if (JsonLd::isA<TouristAttractionVisit>(res)) {
         return res.value<TouristAttractionVisit>().departureTime();
